@@ -282,7 +282,7 @@ pub mod user_request;
 pub use self::user_request::UserRequest;
 pub mod web_rtc_event;
 pub use self::web_rtc_event::WebRtcEvent;
+pub mod web_rtc_event_name;
+pub use self::web_rtc_event_name::WebRtcEventName;
 pub mod web_rtc_event_request;
 pub use self::web_rtc_event_request::WebRtcEventRequest;
-pub mod web_rtc_event_type;
-pub use self::web_rtc_event_type::WebRtcEventType;
